# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ErrorCode(str, Enum):
    """
    ErrorCode
    """

    """
    allowed enum values
    """
    ACTIVE_UNPLANNED_OUTAGE_EXISTS = 'ACTIVE_UNPLANNED_OUTAGE_EXISTS'
    ALREADY_EXPIRED = 'ALREADY_EXPIRED'
    API_CONTRACT_VALIDATION_ERROR = 'API_CONTRACT_VALIDATION_ERROR'
    API_KEY_NAME_NOT_UNIQUE = 'API_KEY_NAME_NOT_UNIQUE'
    AUCTION_BATCH_CREATE_UNAVAILABLE = 'AUCTION_BATCH_CREATE_UNAVAILABLE'
    AUCTION_RESULTS_NOT_AVAILABLE = 'AUCTION_RESULTS_NOT_AVAILABLE'
    AUCTION_UNDER_PROCESSING = 'AUCTION_UNDER_PROCESSING'
    AUTH_METHOD_MISMATCH = 'AUTH_METHOD_MISMATCH'
    BIDDING_NOT_POSSIBLE = 'BIDDING_NOT_POSSIBLE'
    BUSINESS_DAY_PERIOD_TOO_LONG = 'BUSINESS_DAY_PERIOD_TOO_LONG'
    CANCEL_DEADLINE_MISSED = 'CANCEL_DEADLINE_MISSED'
    CANNOT_IMPERSONATE_SELF = 'CANNOT_IMPERSONATE_SELF'
    CANNOT_IMPERSONATE_NESTED = 'CANNOT_IMPERSONATE_NESTED'
    CAPACTY_ALREADY_ALLOCATED = 'CAPACTY_ALREADY_ALLOCATED'
    CLOSURE_TIMES_MISALIGNED = 'CLOSURE_TIMES_MISALIGNED'
    CREDIT_LIMIT_EXCEEDED = 'CREDIT_LIMIT_EXCEEDED'
    CREDIT_LIMIT_TO_BE_EXCEECED = 'CREDIT_LIMIT_TO_BE_EXCEECED'
    CURTAILMENT_NOT_POSSIBLE = 'CURTAILMENT_NOT_POSSIBLE'
    DELIVERY_DAY_TOO_EARLY = 'DELIVERY_DAY_TOO_EARLY'
    DELIVERY_DAY_TOO_LATE = 'DELIVERY_DAY_TOO_LATE'
    DELIVERY_DAY_TOO_SOON = 'DELIVERY_DAY_TOO_SOON'
    DELIVERY_PERIOD_END_TOO_LATE = 'DELIVERY_PERIOD_END_TOO_LATE'
    DELIVERY_PERIOD_ERROR = 'DELIVERY_PERIOD_ERROR'
    DELIVERY_PERIOD_START_TOO_SOON = 'DELIVERY_PERIOD_START_TOO_SOON'
    DELIVERY_PERIOD_TOO_LONG = 'DELIVERY_PERIOD_TOO_LONG'
    DATA_FLOW_NOT_CREATABLE = 'DATA_FLOW_NOT_CREATABLE'
    DATA_FLOW_NOT_EDITABLE = 'DATA_FLOW_NOT_EDITABLE'
    DATA_FLOW_UNDER_PROCESSING = 'DATA_FLOW_UNDER_PROCESSING'
    DATE_IN_PAST_ERROR = 'DATE_IN_PAST_ERROR'
    DATE_PERIOD_MISALIGNED = 'DATE_PERIOD_MISALIGNED'
    DATE_PERIOD_TOO_LONG = 'DATE_PERIOD_TOO_LONG'
    DELETE_DEADLINE_MISSED = 'DELETE_DEADLINE_MISSED'
    DISMISS_BPP_NOT_POSSIBLE = 'DISMISS_BPP_NOT_POSSIBLE'
    DISMISS_CURTAILMENT_NOT_POSSIBLE = 'DISMISS_CURTAILMENT_NOT_POSSIBLE'
    EIC_CODE_SHOULD_BE_UNIQUE = 'EIC_CODE_SHOULD_BE_UNIQUE'
    EMAIL_ADDRESS_NOT_UNIQUE = 'EMAIL_ADDRESS_NOT_UNIQUE'
    ENTITY_CANNOT_BE_UPDATED = 'ENTITY_CANNOT_BE_UPDATED'
    EXECUTION_PERIOD_TOO_LONG = 'EXECUTION_PERIOD_TOO_LONG'
    FIRST_DAY_TOO_SOON = 'FIRST_DAY_TOO_SOON'
    FIRST_MTU_STARTED = 'FIRST_MTU_STARTED'
    FIRST_MTU_ERROR = 'FIRST_MTU_ERROR'
    FORBIDDEN = 'FORBIDDEN'
    GATE_CLOSE_TOO_CLOSE_TO_MTU = 'GATE_CLOSE_TOO_CLOSE_TO_MTU'
    GATE_MISALIGNED = 'GATE_MISALIGNED'
    GATE_OPEN_TOO_LATE = 'GATE_OPEN_TOO_LATE'
    GLOBAL_MTU_SIZE_MISMATCH = 'GLOBAL_MTU_SIZE_MISMATCH'
    HELPDESK_PIN_SHOULD_BE_UNIQUE = 'HELPDESK_PIN_SHOULD_BE_UNIQUE'
    INTERNAL_SERVER_ERROR = 'INTERNAL_SERVER_ERROR'
    INVALID_ACCOUNTING_CODE = 'INVALID_ACCOUNTING_CODE'
    INVALID_ATTACHMENT_FILE_TYPE = 'INVALID_ATTACHMENT_FILE_TYPE'
    INVALID_ATTACHMENT_ID = 'INVALID_ATTACHMENT_ID'
    INVALID_BID_ID = 'INVALID_BID_ID'
    INVALID_BID_CAPACITY = 'INVALID_BID_CAPACITY'
    INVALID_BPP_MARKET = 'INVALID_BPP_MARKET'
    INVALID_BID_PRICE = 'INVALID_BID_PRICE'
    INVALID_BPP_PROVIDER = 'INVALID_BPP_PROVIDER'
    INVALID_CLOSURE_TIME = 'INVALID_CLOSURE_TIME'
    INVALID_DIRECTION_ENTRIES = 'INVALID_DIRECTION_ENTRIES'
    INVALID_DIRECTIONAL_VALUES = 'INVALID_DIRECTIONAL_VALUES'
    INVALID_DELIVERY_DAY = 'INVALID_DELIVERY_DAY'
    INVALID_EXECUTION_DAY = 'INVALID_EXECUTION_DAY'
    INVALID_EXPIRY_DAY = 'INVALID_EXPIRY_DAY'
    INVALID_ID_AUCTION_PRODUCT_TYPE = 'INVALID_ID_AUCTION_PRODUCT_TYPE'
    INVALID_LINE_ITEM_ID = 'INVALID_LINE_ITEM_ID'
    INVALID_MTU = 'INVALID_MTU'
    INVALID_NEW_PERIOD_START = 'INVALID_NEW_PERIOD_START'
    INVALID_NOMINATION_VALUE = 'INVALID_NOMINATION_VALUE'
    INVALID_NOTICEBOARD_ENTRY = 'INVALID_NOTICEBOARD_ENTRY'
    INVALID_NOTICE_CAPACITY = 'INVALID_NOTICE_CAPACITY'
    INVALID_NOTICE_PRICE = 'INVALID_NOTICE_PRICE'
    INVALID_NTC_OVERRIDE_VALUE = 'INVALID_NTC_OVERRIDE_VALUE'
    INVALID_ORGANISATION_ID = 'INVALID_ORGANISATION_ID'
    INVALID_OUTAGE_PERIOD_VALUE = 'INVALID_OUTAGE_PERIOD_VALUE'
    INVALID_PARTICIPANT_EIC_CODE = 'INVALID_PARTICIPANT_EIC_CODE'
    INVALID_PARTICIPANT_ID = 'INVALID_PARTICIPANT_ID'
    INVALID_PERIOD_AMOUNT = 'INVALID_PERIOD_AMOUNT'
    INVALID_PURCHASE_VALUE = 'INVALID_PURCHASE_VALUE'
    INVALID_RESERVE_PRICE = 'INVALID_RESERVE_PRICE'
    INVALID_RESPONSE_CAPACITY = 'INVALID_RESPONSE_CAPACITY'
    INVALID_RESPONSE_PRICE = 'INVALID_RESPONSE_PRICE'
    INVALID_RETURN_CAPACITY = 'INVALID_RETURN_CAPACITY'
    RETURNS_WINDOW_CLOSED = 'RETURNS_WINDOW_CLOSED'
    INVALID_STATUS = 'INVALID_STATUS'
    INVALID_SUBMISSION_ID = 'INVALID_SUBMISSION_ID'
    INVALID_TARGET_NTC_VALUE = 'INVALID_TARGET_NTC_VALUE'
    INVALID_TRADE_TYPE = 'INVALID_TRADE_TYPE'
    INVALID_TRANSFER_CAPACITY = 'INVALID_TRANSFER_CAPACITY'
    INVALID_TSO_ID = 'INVALID_TSO_ID'
    INVALID_UNPLANNED_OUTAGE_ID = 'INVALID_UNPLANNED_OUTAGE_ID'
    INVALID_USER_ID = 'INVALID_USER_ID'
    INVALID_WORKFLOW_TYPE_ID = 'INVALID_WORKFLOW_TYPE_ID'
    LAST_DAY_TOO_LATE = 'LAST_DAY_TOO_LATE'
    LONG_TERM_DELIVERY_PERIOD_MISMATCH = 'LONG_TERM_DELIVERY_PERIOD_MISMATCH'
    MARKET_NOMINATION_SETTING_LOCKED = 'MARKET_NOMINATION_SETTING_LOCKED'
    MARKET_NOMINATION_SETTING_MISMATCH = 'MARKET_NOMINATION_SETTING_MISMATCH'
    MISSING_CANCELLATION_MESSAGE = 'MISSING_CANCELLATION_MESSAGE'
    MISSING_DIRECTIONAL_CONFIG = 'MISSING_DIRECTIONAL_CONFIG'
    MISSING_EXECUTION_MESSAGE = 'MISSING_EXECUTION_MESSAGE'
    MISSING_MANUAL_VALUE = 'MISSING_MANUAL_VALUE'
    MISSING_PRIORITY = 'MISSING_PRIORITY'
    MISSING_VAT_RATE_MARKET = 'MISSING_VAT_RATE_MARKET'
    MTU_BORDER_MISMATCH = 'MTU_BORDER_MISMATCH'
    MTU_LIST_GATES_MISALIGNED = 'MTU_LIST_GATES_MISALIGNED'
    MTU_LIST_MISALIGNED = 'MTU_LIST_MISALIGNED'
    MTU_NOT_EDITABLE = 'MTU_NOT_EDITABLE'
    MTU_PERIOD_OVERLAP = 'MTU_PERIOD_OVERLAP'
    MTU_ALREADY_LOCKED = 'MTU_ALREADY_LOCKED'
    NO_ACTIVE_CRISIS = 'NO_ACTIVE_CRISIS'
    NO_EXCHANGE_RATE = 'NO_EXCHANGE_RATE'
    NO_OFFERS_PRESENT = 'NO_OFFERS_PRESENT'
    NOT_FOUND = 'NOT_FOUND'
    OC_DEFINITION_MISMATCH = 'OC_DEFINITION_MISMATCH'
    OC_LARGER_THAN_MAX_ATC = 'OC_LARGER_THAN_MAX_ATC'
    OC_UNDEFINED = 'OC_UNDEFINED'
    OC_VALUE_MISMATCH = 'OC_VALUE_MISMATCH'
    ORGANISATION_CANNOT_BE_LOCKED = 'ORGANISATION_CANNOT_BE_LOCKED'
    ORGANISATION_NAME_MUST_BE_UNIQUE = 'ORGANISATION_NAME_MUST_BE_UNIQUE'
    ORGANISATION_TYPE_MISMATCH = 'ORGANISATION_TYPE_MISMATCH'
    OUTAGE_CANNOT_BE_EXTENDED = 'OUTAGE_CANNOT_BE_EXTENDED'
    OUTAGE_PERIOD_CANNOT_BE_REMOVED = 'OUTAGE_PERIOD_CANNOT_BE_REMOVED'
    OUTAGE_PERIOD_TOO_SHORT = 'OUTAGE_PERIOD_TOO_SHORT'
    OUTAGE_PERIODS_CROSS_OVER_YEAR = 'OUTAGE_PERIODS_CROSS_OVER_YEAR'
    OUTAGE_PERIODS_UNORDERED = 'OUTAGE_PERIODS_UNORDERED'
    PERIOD_CANNOT_BE_REMOVED = 'PERIOD_CANNOT_BE_REMOVED'
    PERIOD_END_TOO_LATE = 'PERIOD_END_TOO_LATE'
    PERIOD_MISALIGNED = 'PERIOD_MISALIGNED'
    PERIOD_OVERLAP = 'PERIOD_OVERLAP'
    PERIOD_START_TOO_SOON = 'PERIOD_START_TOO_SOON'
    PERIOD_TOO_LONG = 'PERIOD_TOO_LONG'
    PERIOD_NOT_WHOLE_MONTHS = 'PERIOD_NOT_WHOLE_MONTHS'
    PERIODS_OVERLAP = 'PERIODS_OVERLAP'
    PERIODS_UNORDERED = 'PERIODS_UNORDERED'
    PRICE_RANGE_MISMATCH = 'PRICE_RANGE_MISMATCH'
    PROCESS_STEPS_DST_ERROR = 'PROCESS_STEPS_DST_ERROR'
    PROCESS_STEPS_MISALIGNED = 'PROCESS_STEPS_MISALIGNED'
    PROCESS_STEPS_GAP_ERROR = 'PROCESS_STEPS_GAP_ERROR'
    PROCESS_STEP_PRECISION_ERROR = 'PROCESS_STEP_PRECISION_ERROR'
    PROCESS_STEP_BOUNDARY_ERROR = 'PROCESS_STEP_BOUNDARY_ERROR'
    PROCESSING_ERROR = 'PROCESSING_ERROR'
    PRODUCT_TYPE_MISMATCH = 'PRODUCT_TYPE_MISMATCH'
    REPORTING_PERIOD_OVERLAP = 'REPORTING_PERIOD_OVERLAP'
    ROLE_MISMATCH = 'ROLE_MISMATCH'
    SCHEMA_MISMATCH = 'SCHEMA_MISMATCH'
    SCHEMA_VALIDATION_ERROR = 'SCHEMA_VALIDATION_ERROR'
    STATIC_TASK_ALREADY_COMPLETED = 'STATIC_TASK_ALREADY_COMPLETED'
    STATUS_MISMATCH = 'STATUS_MISMATCH'
    TARGET_NTC_MISSING = 'TARGET_NTC_MISSING'
    TIMESCALE_MISMATCH = 'TIMESCALE_MISMATCH'
    TOO_MANY_BIDS = 'TOO_MANY_BIDS'
    TRANSFER_DATE_PERIOD_TOO_LONG = 'TRANSFER_DATE_PERIOD_TOO_LONG'
    TRANCHE_SIZE_MISMATCH = 'TRANCHE_SIZE_MISMATCH'
    UNAUTHORIZED = 'UNAUTHORIZED'
    UNDER_MTU_SIZE_MINIMUM = 'UNDER_MTU_SIZE_MINIMUM'
    UPDATE_DEADLINE_MISSED = 'UPDATE_DEADLINE_MISSED'
    VALIDITY_PERIOD_MISMATCH = 'VALIDITY_PERIOD_MISMATCH'
    VAT_NUMBER_MISSING = 'VAT_NUMBER_MISSING'
    VAT_RATE_MARKET_MISMATCH = 'VAT_RATE_MARKET_MISMATCH'
    VERSION_MISMATCH = 'VERSION_MISMATCH'
    WINDOW_OPEN_TIME_OUT_OF_BOUNDS = 'WINDOW_OPEN_TIME_OUT_OF_BOUNDS'
    WINDOW_CLOSE_TIME_OUT_OF_BOUNDS = 'WINDOW_CLOSE_TIME_OUT_OF_BOUNDS'

    @classmethod
    def from_json(cls, json_str: str) -> ErrorCode:
        """Create an instance of ErrorCode from a JSON string"""
        return ErrorCode(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class UserRole(str, Enum):
    """
    UserRole
    """

    """
    allowed enum values
    """
    ICO_ADMIN_BDL = 'ICO_ADMIN_BDL'
    ICO_ADMIN_HELPDESK = 'ICO_ADMIN_HELPDESK'
    ICO_ONCALL_MGR = 'ICO_ONCALL_MGR'
    ICO_ONCALL_MGR_AUCT = 'ICO_ONCALL_MGR_AUCT'
    ICO_ONCALL_MGR_FIN = 'ICO_ONCALL_MGR_FIN'
    ICO_ONCALL_ANALYST = 'ICO_ONCALL_ANALYST'
    ICO_ONCALL_ANALYIST_AUCT = 'ICO_ONCALL_ANALYIST_AUCT'
    ICO_ONCALL_TRAINING = 'ICO_ONCALL_TRAINING'
    ICO_FINANCE = 'ICO_FINANCE'
    ICO_VIEW = 'ICO_VIEW'
    ICO_VIEW_AUCT = 'ICO_VIEW_AUCT'
    TSO_USER = 'TSO_USER'
    PART_ADMIN = 'PART_ADMIN'
    PART_TRADER = 'PART_TRADER'
    PART_NOMINATOR = 'PART_NOMINATOR'
    PART_NOM_TRADER = 'PART_NOM_TRADER'
    PART_VIEW = 'PART_VIEW'

    @classmethod
    def from_json(cls, json_str: str) -> UserRole:
        """Create an instance of UserRole from a JSON string"""
        return UserRole(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_noticeboard_entry import CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestCreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry(unittest.TestCase):
    """CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry`
        """
        model = empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_noticeboard_entry.CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry()  # noqa: E501
        if include_optional :
            return CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry(
                type = 'BUY', 
                timescale = 'LONG_TERM', 
                delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                direction = 'GB_NL', 
                mtus = [
                    empire_platform_api_public_client.models.secondary_market_capacity_price_mtu.SecondaryMarketCapacityPriceMtu(
                        mtu = '2022-01-04T10:00Z', 
                        capacity = 56, 
                        price = 1.337, )
                    ]
            )
        else :
            return CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry(
                type = 'BUY',
                timescale = 'LONG_TERM',
                delivery_day = 'Tue Jan 04 00:00:00 UTC 2022',
                direction = 'GB_NL',
                mtus = [
                    empire_platform_api_public_client.models.secondary_market_capacity_price_mtu.SecondaryMarketCapacityPriceMtu(
                        mtu = '2022-01-04T10:00Z', 
                        capacity = 56, 
                        price = 1.337, )
                    ],
        )
        """

    def testCreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry(self):
        """Test CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import datetime

from pydantic import Field, StrictStr, conint, conlist

from typing import Optional

from empire_platform_api_public_client.models.auction_product_type import AuctionProductType
from empire_platform_api_public_client.models.border_direction_with_both import BorderDirectionWithBoth
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request import CreateDayAheadOrIntraDayDefaultBidRequest
from empire_platform_api_public_client.models.create_long_term_default_bid_request import CreateLongTermDefaultBidRequest
from empire_platform_api_public_client.models.created_default_bid import CreatedDefaultBid
from empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid import DayAheadOrIntraDayDefaultBid
from empire_platform_api_public_client.models.default_bid_batch import DefaultBidBatch
from empire_platform_api_public_client.models.default_bid_options import DefaultBidOptions
from empire_platform_api_public_client.models.default_bid_sort_by import DefaultBidSortBy
from empire_platform_api_public_client.models.long_term_default_bid import LongTermDefaultBid
from empire_platform_api_public_client.models.update_day_ahead_or_intra_day_default_bid_request import UpdateDayAheadOrIntraDayDefaultBidRequest
from empire_platform_api_public_client.models.update_long_term_default_bid_request import UpdateLongTermDefaultBidRequest

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DefaultBidApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_day_ahead_or_intra_day_default_bid(self, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], create_day_ahead_or_intra_day_default_bid_request : CreateDayAheadOrIntraDayDefaultBidRequest, **kwargs) -> CreatedDefaultBid:  # noqa: E501
        """create_day_ahead_or_intra_day_default_bid  # noqa: E501

        Create new Default Bid for Day Ahead or Intra Day product types  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `CREATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_day_ahead_or_intra_day_default_bid(x_participant_id, create_day_ahead_or_intra_day_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param create_day_ahead_or_intra_day_default_bid_request: (required)
        :type create_day_ahead_or_intra_day_default_bid_request: CreateDayAheadOrIntraDayDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreatedDefaultBid
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the create_day_ahead_or_intra_day_default_bid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.create_day_ahead_or_intra_day_default_bid_with_http_info(x_participant_id, create_day_ahead_or_intra_day_default_bid_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_day_ahead_or_intra_day_default_bid_with_http_info(self, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], create_day_ahead_or_intra_day_default_bid_request : CreateDayAheadOrIntraDayDefaultBidRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """create_day_ahead_or_intra_day_default_bid  # noqa: E501

        Create new Default Bid for Day Ahead or Intra Day product types  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `CREATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_day_ahead_or_intra_day_default_bid_with_http_info(x_participant_id, create_day_ahead_or_intra_day_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param create_day_ahead_or_intra_day_default_bid_request: (required)
        :type create_day_ahead_or_intra_day_default_bid_request: CreateDayAheadOrIntraDayDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreatedDefaultBid, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'x_participant_id',
            'create_day_ahead_or_intra_day_default_bid_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_day_ahead_or_intra_day_default_bid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_id']:
            _header_params['X-Participant-Id'] = _params['x_participant_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['create_day_ahead_or_intra_day_default_bid_request'] is not None:
            _body_params = _params['create_day_ahead_or_intra_day_default_bid_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '201': "CreatedDefaultBid",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/default-bids/day-ahead-or-intra-day', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_long_term_default_bid(self, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], create_long_term_default_bid_request : CreateLongTermDefaultBidRequest, **kwargs) -> CreatedDefaultBid:  # noqa: E501
        """create_long_term_default_bid  # noqa: E501

        Create new Default Bid for Long Term product types  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `CREATE_LONG_TERM_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_long_term_default_bid(x_participant_id, create_long_term_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param create_long_term_default_bid_request: (required)
        :type create_long_term_default_bid_request: CreateLongTermDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreatedDefaultBid
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the create_long_term_default_bid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.create_long_term_default_bid_with_http_info(x_participant_id, create_long_term_default_bid_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_long_term_default_bid_with_http_info(self, x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], create_long_term_default_bid_request : CreateLongTermDefaultBidRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """create_long_term_default_bid  # noqa: E501

        Create new Default Bid for Long Term product types  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `CREATE_LONG_TERM_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_long_term_default_bid_with_http_info(x_participant_id, create_long_term_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param create_long_term_default_bid_request: (required)
        :type create_long_term_default_bid_request: CreateLongTermDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreatedDefaultBid, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'x_participant_id',
            'create_long_term_default_bid_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_long_term_default_bid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_id']:
            _header_params['X-Participant-Id'] = _params['x_participant_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['create_long_term_default_bid_request'] is not None:
            _body_params = _params['create_long_term_default_bid_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '201': "CreatedDefaultBid",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/default-bids/long-term', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_default_bid(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> None:  # noqa: E501
        """delete_default_bid  # noqa: E501

        Delete an existing Default Bid  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `DELETE_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_default_bid(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the delete_default_bid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.delete_default_bid_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_default_bid_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """delete_default_bid  # noqa: E501

        Delete an existing Default Bid  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `DELETE_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_default_bid_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_default_bid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/default-bids/{id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_day_ahead_or_intra_day_default_bid(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> DayAheadOrIntraDayDefaultBid:  # noqa: E501
        """get_day_ahead_or_intra_day_default_bid  # noqa: E501

        Fetch a Day Ahead or Intra Day Default Bid by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_day_ahead_or_intra_day_default_bid(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DayAheadOrIntraDayDefaultBid
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_day_ahead_or_intra_day_default_bid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_day_ahead_or_intra_day_default_bid_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_day_ahead_or_intra_day_default_bid_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_day_ahead_or_intra_day_default_bid  # noqa: E501

        Fetch a Day Ahead or Intra Day Default Bid by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_day_ahead_or_intra_day_default_bid_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DayAheadOrIntraDayDefaultBid, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_day_ahead_or_intra_day_default_bid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "DayAheadOrIntraDayDefaultBid",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/default-bids/day-ahead-or-intra-day/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_default_bid_options(self, **kwargs) -> DefaultBidOptions:  # noqa: E501
        """get_default_bid_options  # noqa: E501

        Fetch options for creating and all kinds of Default Bids  Returns allocation MTU size configuration for Auction Product Types  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `MANAGE_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_default_bid_options(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DefaultBidOptions
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_default_bid_options_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_default_bid_options_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def get_default_bid_options_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """get_default_bid_options  # noqa: E501

        Fetch options for creating and all kinds of Default Bids  Returns allocation MTU size configuration for Auction Product Types  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `MANAGE_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_default_bid_options_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DefaultBidOptions, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_default_bid_options" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "DefaultBidOptions",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/default-bids/options', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_default_bids(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[DefaultBidSortBy, Field(..., description="Sort list by given attribute and direction")], x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], product_types : Annotated[conlist(AuctionProductType), Field(..., description="List of Auction Product Types")], border_direction : Annotated[BorderDirectionWithBoth, Field(..., description="Border Direction with additional 'BOTH' option")], delivery_period_start : Annotated[datetime, Field(..., description="Filter for start of delivery period (aligned to MTUs)")], delivery_period_end : Annotated[datetime, Field(..., description="Filter for end of delivery period (aligned to MTUs)")], validity_period_start : Annotated[Optional[datetime], Field(description="Filter for start of validity period (optional)")] = None, validity_period_end : Annotated[Optional[datetime], Field(description="Filter for end of validity period (optional)")] = None, **kwargs) -> DefaultBidBatch:  # noqa: E501
        """get_default_bids  # noqa: E501

        Fetch Default Bids for a given Participant  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_default_bids(limit, offset, sort_by, x_participant_id, product_types, border_direction, delivery_period_start, delivery_period_end, validity_period_start, validity_period_end, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: DefaultBidSortBy
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param product_types: List of Auction Product Types (required)
        :type product_types: List[AuctionProductType]
        :param border_direction: Border Direction with additional 'BOTH' option (required)
        :type border_direction: BorderDirectionWithBoth
        :param delivery_period_start: Filter for start of delivery period (aligned to MTUs) (required)
        :type delivery_period_start: datetime
        :param delivery_period_end: Filter for end of delivery period (aligned to MTUs) (required)
        :type delivery_period_end: datetime
        :param validity_period_start: Filter for start of validity period (optional)
        :type validity_period_start: datetime
        :param validity_period_end: Filter for end of validity period (optional)
        :type validity_period_end: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DefaultBidBatch
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_default_bids_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_default_bids_with_http_info(limit, offset, sort_by, x_participant_id, product_types, border_direction, delivery_period_start, delivery_period_end, validity_period_start, validity_period_end, **kwargs)  # noqa: E501

    @validate_arguments
    def get_default_bids_with_http_info(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[DefaultBidSortBy, Field(..., description="Sort list by given attribute and direction")], x_participant_id : Annotated[StrictStr, Field(..., description="Internal ID of a Participant-type Organisation")], product_types : Annotated[conlist(AuctionProductType), Field(..., description="List of Auction Product Types")], border_direction : Annotated[BorderDirectionWithBoth, Field(..., description="Border Direction with additional 'BOTH' option")], delivery_period_start : Annotated[datetime, Field(..., description="Filter for start of delivery period (aligned to MTUs)")], delivery_period_end : Annotated[datetime, Field(..., description="Filter for end of delivery period (aligned to MTUs)")], validity_period_start : Annotated[Optional[datetime], Field(description="Filter for start of validity period (optional)")] = None, validity_period_end : Annotated[Optional[datetime], Field(description="Filter for end of validity period (optional)")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_default_bids  # noqa: E501

        Fetch Default Bids for a given Participant  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_default_bids_with_http_info(limit, offset, sort_by, x_participant_id, product_types, border_direction, delivery_period_start, delivery_period_end, validity_period_start, validity_period_end, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: DefaultBidSortBy
        :param x_participant_id: Internal ID of a Participant-type Organisation (required)
        :type x_participant_id: str
        :param product_types: List of Auction Product Types (required)
        :type product_types: List[AuctionProductType]
        :param border_direction: Border Direction with additional 'BOTH' option (required)
        :type border_direction: BorderDirectionWithBoth
        :param delivery_period_start: Filter for start of delivery period (aligned to MTUs) (required)
        :type delivery_period_start: datetime
        :param delivery_period_end: Filter for end of delivery period (aligned to MTUs) (required)
        :type delivery_period_end: datetime
        :param validity_period_start: Filter for start of validity period (optional)
        :type validity_period_start: datetime
        :param validity_period_end: Filter for end of validity period (optional)
        :type validity_period_end: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DefaultBidBatch, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset',
            'sort_by',
            'x_participant_id',
            'product_types',
            'border_direction',
            'delivery_period_start',
            'delivery_period_end',
            'validity_period_start',
            'validity_period_end'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_default_bids" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('product_types') is not None:  # noqa: E501
            _query_params.append(('productTypes', _params['product_types']))
            _collection_formats['productTypes'] = 'multi'

        if _params.get('border_direction') is not None:  # noqa: E501
            _query_params.append(('borderDirection', _params['border_direction'].value))

        if _params.get('delivery_period_start') is not None:  # noqa: E501
            if isinstance(_params['delivery_period_start'], datetime):
                _query_params.append(('deliveryPeriodStart', _params['delivery_period_start'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('deliveryPeriodStart', _params['delivery_period_start']))

        if _params.get('delivery_period_end') is not None:  # noqa: E501
            if isinstance(_params['delivery_period_end'], datetime):
                _query_params.append(('deliveryPeriodEnd', _params['delivery_period_end'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('deliveryPeriodEnd', _params['delivery_period_end']))

        if _params.get('validity_period_start') is not None:  # noqa: E501
            if isinstance(_params['validity_period_start'], datetime):
                _query_params.append(('validityPeriodStart', _params['validity_period_start'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('validityPeriodStart', _params['validity_period_start']))

        if _params.get('validity_period_end') is not None:  # noqa: E501
            if isinstance(_params['validity_period_end'], datetime):
                _query_params.append(('validityPeriodEnd', _params['validity_period_end'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('validityPeriodEnd', _params['validity_period_end']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_participant_id']:
            _header_params['X-Participant-Id'] = _params['x_participant_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "DefaultBidBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/default-bids', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_long_term_default_bid(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> LongTermDefaultBid:  # noqa: E501
        """get_long_term_default_bid  # noqa: E501

        Fetch a Long Term Default Bid by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_long_term_default_bid(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LongTermDefaultBid
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_long_term_default_bid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_long_term_default_bid_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_long_term_default_bid_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_long_term_default_bid  # noqa: E501

        Fetch a Long Term Default Bid by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_DEFAULT_BIDS`   * `VIEW_ANY_DEFAULT_BIDS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_long_term_default_bid_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LongTermDefaultBid, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_long_term_default_bid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "LongTermDefaultBid",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/default-bids/long-term/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_day_ahead_or_intra_day_default_bid(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], update_day_ahead_or_intra_day_default_bid_request : UpdateDayAheadOrIntraDayDefaultBidRequest, **kwargs) -> None:  # noqa: E501
        """update_day_ahead_or_intra_day_default_bid  # noqa: E501

        Update a Day Ahead or Intra Day Default Bid by its identifier  Re-creates any existing default bid values  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `UPDATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_day_ahead_or_intra_day_default_bid(id, update_day_ahead_or_intra_day_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param update_day_ahead_or_intra_day_default_bid_request: (required)
        :type update_day_ahead_or_intra_day_default_bid_request: UpdateDayAheadOrIntraDayDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the update_day_ahead_or_intra_day_default_bid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.update_day_ahead_or_intra_day_default_bid_with_http_info(id, update_day_ahead_or_intra_day_default_bid_request, **kwargs)  # noqa: E501

    @validate_arguments
    def update_day_ahead_or_intra_day_default_bid_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], update_day_ahead_or_intra_day_default_bid_request : UpdateDayAheadOrIntraDayDefaultBidRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """update_day_ahead_or_intra_day_default_bid  # noqa: E501

        Update a Day Ahead or Intra Day Default Bid by its identifier  Re-creates any existing default bid values  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `UPDATE_DAY_AHEAD_OR_INTRA_DAY_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_day_ahead_or_intra_day_default_bid_with_http_info(id, update_day_ahead_or_intra_day_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param update_day_ahead_or_intra_day_default_bid_request: (required)
        :type update_day_ahead_or_intra_day_default_bid_request: UpdateDayAheadOrIntraDayDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id',
            'update_day_ahead_or_intra_day_default_bid_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_day_ahead_or_intra_day_default_bid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['update_day_ahead_or_intra_day_default_bid_request'] is not None:
            _body_params = _params['update_day_ahead_or_intra_day_default_bid_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/default-bids/day-ahead-or-intra-day/{id}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_long_term_default_bid(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], update_long_term_default_bid_request : UpdateLongTermDefaultBidRequest, **kwargs) -> None:  # noqa: E501
        """update_long_term_default_bid  # noqa: E501

        Updat a Long Term Default Bid by its identifier  Re-creates any existing default bid values  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `UPDATE_LONG_TERM_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_long_term_default_bid(id, update_long_term_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param update_long_term_default_bid_request: (required)
        :type update_long_term_default_bid_request: UpdateLongTermDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the update_long_term_default_bid_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.update_long_term_default_bid_with_http_info(id, update_long_term_default_bid_request, **kwargs)  # noqa: E501

    @validate_arguments
    def update_long_term_default_bid_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], update_long_term_default_bid_request : UpdateLongTermDefaultBidRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """update_long_term_default_bid  # noqa: E501

        Updat a Long Term Default Bid by its identifier  Re-creates any existing default bid values  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_DEFAULT_BIDS`   * `MANAGE_ANY_DEFAULT_BIDS`  __Generates Audit Log Entry:__ `UPDATE_LONG_TERM_DEFAULT_BID`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_long_term_default_bid_with_http_info(id, update_long_term_default_bid_request, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param update_long_term_default_bid_request: (required)
        :type update_long_term_default_bid_request: UpdateLongTermDefaultBidRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id',
            'update_long_term_default_bid_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_long_term_default_bid" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['update_long_term_default_bid_request'] is not None:
            _body_params = _params['update_long_term_default_bid_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/default-bids/long-term/{id}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuctionProductType(str, Enum):
    """
    Auction product type. Each product type is part of a larger group, shown by the prefix of each value: - `LT_*` - Long Term - `DA_*` - Day Ahead - `ID_*` - Intra Day 
    """

    """
    allowed enum values
    """
    LT_EXPLICIT_MULTI_ANNUAL = 'LT_EXPLICIT_MULTI_ANNUAL'
    LT_EXPLICIT_ANNUAL = 'LT_EXPLICIT_ANNUAL'
    LT_EXPLICIT_SEASONAL = 'LT_EXPLICIT_SEASONAL'
    LT_EXPLICIT_QUARTERLY = 'LT_EXPLICIT_QUARTERLY'
    LT_EXPLICIT_MONTHLY = 'LT_EXPLICIT_MONTHLY'
    LT_EXPLICIT_MULTIDAY = 'LT_EXPLICIT_MULTIDAY'
    LT_EXPLICIT_WEEKLY = 'LT_EXPLICIT_WEEKLY'
    LT_EXPLICIT_WEEKEND = 'LT_EXPLICIT_WEEKEND'
    LT_EXPLICIT_LONG_WEEKEND = 'LT_EXPLICIT_LONG_WEEKEND'
    DA_EXPLICIT_DA = 'DA_EXPLICIT_DA'
    ID_EXPLICIT_ID_1 = 'ID_EXPLICIT_ID_1'
    ID_EXPLICIT_ID_2 = 'ID_EXPLICIT_ID_2'
    ID_EXPLICIT_ID_3 = 'ID_EXPLICIT_ID_3'
    ID_EXPLICIT_ID_4 = 'ID_EXPLICIT_ID_4'

    @classmethod
    def from_json(cls, json_str: str) -> AuctionProductType:
        """Create an instance of AuctionProductType from a JSON string"""
        return AuctionProductType(json.loads(json_str))





# coding: utf-8

# flake8: noqa
"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from empire_platform_api_public_client.models.address import Address
from empire_platform_api_public_client.models.aggregated_allocated_auction import AggregatedAllocatedAuction
from empire_platform_api_public_client.models.aggregated_nomination_options import AggregatedNominationOptions
from empire_platform_api_public_client.models.aggregated_nomination_options_nominee_participants_inner import AggregatedNominationOptionsNomineeParticipantsInner
from empire_platform_api_public_client.models.aggregated_nomination_type import AggregatedNominationType
from empire_platform_api_public_client.models.aggregated_nominations import AggregatedNominations
from empire_platform_api_public_client.models.aggregated_nominations_mns_or_gb import AggregatedNominationsMnsOrGb
from empire_platform_api_public_client.models.aggregated_nominations_mns_or_gb_mtus_inner import AggregatedNominationsMnsOrGbMtusInner
from empire_platform_api_public_client.models.aggregated_nominations_mtu_netted_nominations import AggregatedNominationsMtuNettedNominations
from empire_platform_api_public_client.models.aggregated_nominations_mtu_value import AggregatedNominationsMtuValue
from empire_platform_api_public_client.models.aggregated_nominations_nl import AggregatedNominationsNl
from empire_platform_api_public_client.models.aggregated_nominations_nl_mtus_inner import AggregatedNominationsNlMtusInner
from empire_platform_api_public_client.models.aggregated_nominations_nl_mtus_inner_eprogram_values import AggregatedNominationsNlMtusInnerEprogramValues
from empire_platform_api_public_client.models.allocated_auction import AllocatedAuction
from empire_platform_api_public_client.models.allocated_auction_batch import AllocatedAuctionBatch
from empire_platform_api_public_client.models.allocated_auction_sort_by import AllocatedAuctionSortBy
from empire_platform_api_public_client.models.api_key import ApiKey
from empire_platform_api_public_client.models.attachment import Attachment
from empire_platform_api_public_client.models.auction import Auction
from empire_platform_api_public_client.models.auction_allocation_resolution import AuctionAllocationResolution
from empire_platform_api_public_client.models.auction_batch import AuctionBatch
from empire_platform_api_public_client.models.auction_bid_participant import AuctionBidParticipant
from empire_platform_api_public_client.models.auction_bid_status import AuctionBidStatus
from empire_platform_api_public_client.models.auction_bidding_configuration import AuctionBiddingConfiguration
from empire_platform_api_public_client.models.auction_bidding_mode import AuctionBiddingMode
from empire_platform_api_public_client.models.auction_intra_day_product_type import AuctionIntraDayProductType
from empire_platform_api_public_client.models.auction_process_steps_absolute import AuctionProcessStepsAbsolute
from empire_platform_api_public_client.models.auction_product_type import AuctionProductType
from empire_platform_api_public_client.models.auction_reduction_period import AuctionReductionPeriod
from empire_platform_api_public_client.models.auction_result_congestion_rent import AuctionResultCongestionRent
from empire_platform_api_public_client.models.auction_result_participant import AuctionResultParticipant
from empire_platform_api_public_client.models.auction_sort_by import AuctionSortBy
from empire_platform_api_public_client.models.auction_status import AuctionStatus
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.audit_log import AuditLog
from empire_platform_api_public_client.models.audit_log_api_key import AuditLogApiKey
from empire_platform_api_public_client.models.audit_log_batch import AuditLogBatch
from empire_platform_api_public_client.models.audit_log_domain import AuditLogDomain
from empire_platform_api_public_client.models.audit_log_payload import AuditLogPayload
from empire_platform_api_public_client.models.audit_log_sort_by import AuditLogSortBy
from empire_platform_api_public_client.models.audit_log_status import AuditLogStatus
from empire_platform_api_public_client.models.audit_log_type import AuditLogType
from empire_platform_api_public_client.models.audit_log_user import AuditLogUser
from empire_platform_api_public_client.models.audit_log_user_organisation import AuditLogUserOrganisation
from empire_platform_api_public_client.models.bid_value import BidValue
from empire_platform_api_public_client.models.bidding_configuration import BiddingConfiguration
from empire_platform_api_public_client.models.bidding_configuration_per_direction import BiddingConfigurationPerDirection
from empire_platform_api_public_client.models.bidding_configuration_secondary_market_notices import BiddingConfigurationSecondaryMarketNotices
from empire_platform_api_public_client.models.bidding_configuration_values_inner import BiddingConfigurationValuesInner
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.border_direction_with_both import BorderDirectionWithBoth
from empire_platform_api_public_client.models.border_direction_with_both_and_none import BorderDirectionWithBothAndNone
from empire_platform_api_public_client.models.buy_now_day_ahead_offer_sort_by import BuyNowDayAheadOfferSortBy
from empire_platform_api_public_client.models.buy_now_offer import BuyNowOffer
from empire_platform_api_public_client.models.buy_now_offer_mtus_inner import BuyNowOfferMtusInner
from empire_platform_api_public_client.models.buy_now_offer_status import BuyNowOfferStatus
from empire_platform_api_public_client.models.create_api_key_request import CreateApiKeyRequest
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request import CreateDayAheadOrIntraDayDefaultBidRequest
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner import CreateDayAheadOrIntraDayDefaultBidRequestBidsInner
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner_mtus_inner import CreateDayAheadOrIntraDayDefaultBidRequestBidsInnerMtusInner
from empire_platform_api_public_client.models.create_default_nomination_request import CreateDefaultNominationRequest
from empire_platform_api_public_client.models.create_long_term_default_bid_request import CreateLongTermDefaultBidRequest
from empire_platform_api_public_client.models.create_organisation_document_request import CreateOrganisationDocumentRequest
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_noticeboard_entry import CreateSecondaryMarketDayAheadOrIntraDayNoticeboardEntry
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_noticeboard_response import CreateSecondaryMarketDayAheadOrIntraDayNoticeboardResponse
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_transfer_request import CreateSecondaryMarketDayAheadOrIntraDayTransferRequest
from empire_platform_api_public_client.models.create_secondary_market_day_ahead_or_intra_day_transfer_request_mtus_inner import CreateSecondaryMarketDayAheadOrIntraDayTransferRequestMtusInner
from empire_platform_api_public_client.models.create_secondary_market_long_term_noticeboard_entry import CreateSecondaryMarketLongTermNoticeboardEntry
from empire_platform_api_public_client.models.create_secondary_market_long_term_noticeboard_response import CreateSecondaryMarketLongTermNoticeboardResponse
from empire_platform_api_public_client.models.create_secondary_market_long_term_transfer_request import CreateSecondaryMarketLongTermTransferRequest
from empire_platform_api_public_client.models.create_secondary_market_return_request import CreateSecondaryMarketReturnRequest
from empire_platform_api_public_client.models.created_api_key import CreatedApiKey
from empire_platform_api_public_client.models.created_default_bid import CreatedDefaultBid
from empire_platform_api_public_client.models.created_default_nomination import CreatedDefaultNomination
from empire_platform_api_public_client.models.created_organisation_document import CreatedOrganisationDocument
from empire_platform_api_public_client.models.created_secondary_market_day_ahead_or_intra_day_noticeboard_entry import CreatedSecondaryMarketDayAheadOrIntraDayNoticeboardEntry
from empire_platform_api_public_client.models.created_secondary_market_day_ahead_or_intra_day_noticeboard_response import CreatedSecondaryMarketDayAheadOrIntraDayNoticeboardResponse
from empire_platform_api_public_client.models.created_secondary_market_day_ahead_or_intra_day_transfer_request import CreatedSecondaryMarketDayAheadOrIntraDayTransferRequest
from empire_platform_api_public_client.models.created_secondary_market_long_term_noticeboard_entry import CreatedSecondaryMarketLongTermNoticeboardEntry
from empire_platform_api_public_client.models.created_secondary_market_long_term_noticeboard_response import CreatedSecondaryMarketLongTermNoticeboardResponse
from empire_platform_api_public_client.models.created_secondary_market_long_term_transfer_request import CreatedSecondaryMarketLongTermTransferRequest
from empire_platform_api_public_client.models.created_secondary_market_return_request_identifier import CreatedSecondaryMarketReturnRequestIdentifier
from empire_platform_api_public_client.models.dashboard_next_nomination_gate import DashboardNextNominationGate
from empire_platform_api_public_client.models.dashboard_next_nomination_gate_window import DashboardNextNominationGateWindow
from empire_platform_api_public_client.models.dashboard_next_nomination_window_status import DashboardNextNominationWindowStatus
from empire_platform_api_public_client.models.date_period import DatePeriod
from empire_platform_api_public_client.models.date_time_period import DateTimePeriod
from empire_platform_api_public_client.models.day_ahead_auction import DayAheadAuction
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group import DayAheadOrIntraDayAuctionBidGroup
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner import DayAheadOrIntraDayAuctionBidGroupBidsInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner_bid import DayAheadOrIntraDayAuctionBidGroupBidsInnerBid
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner_bid_results import DayAheadOrIntraDayAuctionBidGroupBidsInnerBidResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result import DayAheadOrIntraDayAuctionBidGroupResult
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result_batch import DayAheadOrIntraDayAuctionBidGroupResultBatch
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result_bids_inner import DayAheadOrIntraDayAuctionBidGroupResultBidsInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_result_bids_inner_bid import DayAheadOrIntraDayAuctionBidGroupResultBidsInnerBid
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu import DayAheadOrIntraDayAuctionMtu
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu_results import DayAheadOrIntraDayAuctionMtuResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu_results_bids_inner import DayAheadOrIntraDayAuctionMtuResultsBidsInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_participant_results import DayAheadOrIntraDayAuctionParticipantResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_participant_results_mtus_inner import DayAheadOrIntraDayAuctionParticipantResultsMtusInner
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_participant_results_mtus_inner_value import DayAheadOrIntraDayAuctionParticipantResultsMtusInnerValue
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results import DayAheadOrIntraDayAuctionResults
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_results_mtu import DayAheadOrIntraDayAuctionResultsMtu
from empire_platform_api_public_client.models.day_ahead_or_intra_day_default_bid import DayAheadOrIntraDayDefaultBid
from empire_platform_api_public_client.models.default_bid import DefaultBid
from empire_platform_api_public_client.models.default_bid_batch import DefaultBidBatch
from empire_platform_api_public_client.models.default_bid_options import DefaultBidOptions
from empire_platform_api_public_client.models.default_bid_sort_by import DefaultBidSortBy
from empire_platform_api_public_client.models.default_bid_status import DefaultBidStatus
from empire_platform_api_public_client.models.default_nomination import DefaultNomination
from empire_platform_api_public_client.models.default_nomination_batch import DefaultNominationBatch
from empire_platform_api_public_client.models.default_nomination_declaration_type import DefaultNominationDeclarationType
from empire_platform_api_public_client.models.default_nomination_details import DefaultNominationDetails
from empire_platform_api_public_client.models.default_nomination_mtu import DefaultNominationMtu
from empire_platform_api_public_client.models.default_nomination_options import DefaultNominationOptions
from empire_platform_api_public_client.models.default_nomination_sort_by import DefaultNominationSortBy
from empire_platform_api_public_client.models.default_nomination_status import DefaultNominationStatus
from empire_platform_api_public_client.models.error_code import ErrorCode
from empire_platform_api_public_client.models.error_response import ErrorResponse
from empire_platform_api_public_client.models.finance_information import FinanceInformation
from empire_platform_api_public_client.models.finance_information_bank_deposits_inner import FinanceInformationBankDepositsInner
from empire_platform_api_public_client.models.finance_information_letter_of_credits_inner import FinanceInformationLetterOfCreditsInner
from empire_platform_api_public_client.models.finance_information_lockable_amount import FinanceInformationLockableAmount
from empire_platform_api_public_client.models.finance_information_lockable_date import FinanceInformationLockableDate
from empire_platform_api_public_client.models.finance_information_lockable_period import FinanceInformationLockablePeriod
from empire_platform_api_public_client.models.finance_information_market_vat_details import FinanceInformationMarketVatDetails
from empire_platform_api_public_client.models.finance_information_sage_settings import FinanceInformationSageSettings
from empire_platform_api_public_client.models.intra_day_auction import IntraDayAuction
from empire_platform_api_public_client.models.invoice import Invoice
from empire_platform_api_public_client.models.invoice_action_type import InvoiceActionType
from empire_platform_api_public_client.models.invoice_batch import InvoiceBatch
from empire_platform_api_public_client.models.invoice_details import InvoiceDetails
from empire_platform_api_public_client.models.invoice_history import InvoiceHistory
from empire_platform_api_public_client.models.invoice_line_item import InvoiceLineItem
from empire_platform_api_public_client.models.invoice_participant_details import InvoiceParticipantDetails
from empire_platform_api_public_client.models.invoice_status import InvoiceStatus
from empire_platform_api_public_client.models.invoice_summary import InvoiceSummary
from empire_platform_api_public_client.models.invoice_vat_rate import InvoiceVatRate
from empire_platform_api_public_client.models.long_term_auction import LongTermAuction
from empire_platform_api_public_client.models.long_term_auction_bid import LongTermAuctionBid
from empire_platform_api_public_client.models.long_term_auction_bid_result import LongTermAuctionBidResult
from empire_platform_api_public_client.models.long_term_auction_bid_result_batch import LongTermAuctionBidResultBatch
from empire_platform_api_public_client.models.long_term_auction_bid_sort_by import LongTermAuctionBidSortBy
from empire_platform_api_public_client.models.long_term_auction_results import LongTermAuctionResults
from empire_platform_api_public_client.models.long_term_auction_results_allocated_capacity_inner import LongTermAuctionResultsAllocatedCapacityInner
from empire_platform_api_public_client.models.long_term_default_bid import LongTermDefaultBid
from empire_platform_api_public_client.models.long_term_offered_capacity import LongTermOfferedCapacity
from empire_platform_api_public_client.models.long_term_reserve_price import LongTermReservePrice
from empire_platform_api_public_client.models.long_term_reserve_price_steps_inner import LongTermReservePriceStepsInner
from empire_platform_api_public_client.models.manual_file_upload_request import ManualFileUploadRequest
from empire_platform_api_public_client.models.market import Market
from empire_platform_api_public_client.models.message import Message
from empire_platform_api_public_client.models.message_batch import MessageBatch
from empire_platform_api_public_client.models.message_category import MessageCategory
from empire_platform_api_public_client.models.message_sender import MessageSender
from empire_platform_api_public_client.models.message_severity import MessageSeverity
from empire_platform_api_public_client.models.message_sort_by import MessageSortBy
from empire_platform_api_public_client.models.message_type import MessageType
from empire_platform_api_public_client.models.mtu_period import MtuPeriod
from empire_platform_api_public_client.models.mtu_size import MtuSize
from empire_platform_api_public_client.models.mtu_size_per_auction_product_type import MtuSizePerAuctionProductType
from empire_platform_api_public_client.models.mtu_size_per_timescale import MtuSizePerTimescale
from empire_platform_api_public_client.models.nested_error import NestedError
from empire_platform_api_public_client.models.nomination_capacity_resolution import NominationCapacityResolution
from empire_platform_api_public_client.models.nomination_restriction_type import NominationRestrictionType
from empire_platform_api_public_client.models.noticeboard_entry_type import NoticeboardEntryType
from empire_platform_api_public_client.models.noticeboard_entry_type_with_both import NoticeboardEntryTypeWithBoth
from empire_platform_api_public_client.models.notification_preference import NotificationPreference
from empire_platform_api_public_client.models.notification_preference_with_sms import NotificationPreferenceWithSms
from empire_platform_api_public_client.models.ntc_overview_mtu_data import NtcOverviewMtuData
from empire_platform_api_public_client.models.offered_capacity_setup import OfferedCapacitySetup
from empire_platform_api_public_client.models.organisation import Organisation
from empire_platform_api_public_client.models.organisation_auth_method import OrganisationAuthMethod
from empire_platform_api_public_client.models.organisation_contact import OrganisationContact
from empire_platform_api_public_client.models.organisation_contact_information import OrganisationContactInformation
from empire_platform_api_public_client.models.organisation_document import OrganisationDocument
from empire_platform_api_public_client.models.organisation_document_batch import OrganisationDocumentBatch
from empire_platform_api_public_client.models.organisation_document_file_type import OrganisationDocumentFileType
from empire_platform_api_public_client.models.organisation_document_options import OrganisationDocumentOptions
from empire_platform_api_public_client.models.organisation_document_organisation import OrganisationDocumentOrganisation
from empire_platform_api_public_client.models.organisation_document_sort_by import OrganisationDocumentSortBy
from empire_platform_api_public_client.models.organisation_document_status import OrganisationDocumentStatus
from empire_platform_api_public_client.models.organisation_document_uploaded_by_user import OrganisationDocumentUploadedByUser
from empire_platform_api_public_client.models.organisation_document_user import OrganisationDocumentUser
from empire_platform_api_public_client.models.organisation_file_settings import OrganisationFileSettings
from empire_platform_api_public_client.models.organisation_market_settings import OrganisationMarketSettings
from empire_platform_api_public_client.models.organisation_market_settings_gb_nomination_settings import OrganisationMarketSettingsGbNominationSettings
from empire_platform_api_public_client.models.organisation_market_settings_nl_nomination_settings import OrganisationMarketSettingsNlNominationSettings
from empire_platform_api_public_client.models.organisation_status import OrganisationStatus
from empire_platform_api_public_client.models.organisation_type import OrganisationType
from empire_platform_api_public_client.models.organisation_user import OrganisationUser
from empire_platform_api_public_client.models.organisation_user_batch import OrganisationUserBatch
from empire_platform_api_public_client.models.organisation_user_sort_by import OrganisationUserSortBy
from empire_platform_api_public_client.models.other_party import OtherParty
from empire_platform_api_public_client.models.participant import Participant
from empire_platform_api_public_client.models.participant_dashboard_default_bids_and_nominations_data import ParticipantDashboardDefaultBidsAndNominationsData
from empire_platform_api_public_client.models.participant_dashboard_finance_overview_data import ParticipantDashboardFinanceOverviewData
from empire_platform_api_public_client.models.participant_dashboard_finance_overview_invoice import ParticipantDashboardFinanceOverviewInvoice
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data import ParticipantDashboardInterconnectorCapacityData
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_inner import ParticipantDashboardInterconnectorCapacityDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_data_mtus_inner_values_inner import ParticipantDashboardInterconnectorCapacityDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data import ParticipantDashboardInterconnectorCapacityGraphData
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner import ParticipantDashboardInterconnectorCapacityGraphDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_netted_nominations import ParticipantDashboardInterconnectorCapacityGraphDataMtusInnerNettedNominations
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_values_inner import ParticipantDashboardInterconnectorCapacityGraphDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_dashboard_messages import ParticipantDashboardMessages
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data import ParticipantDashboardNettedNominationsData
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner import ParticipantDashboardNettedNominationsDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner_aggregated_nominations_inner import ParticipantDashboardNettedNominationsDataMtusInnerAggregatedNominationsInner
from empire_platform_api_public_client.models.participant_dashboard_netted_nominations_data_mtus_inner_netted_nominations import ParticipantDashboardNettedNominationsDataMtusInnerNettedNominations
from empire_platform_api_public_client.models.participant_dashboard_next_auction import ParticipantDashboardNextAuction
from empire_platform_api_public_client.models.participant_dashboard_next_auctions_and_nomination_gates import ParticipantDashboardNextAuctionsAndNominationGates
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data import ParticipantDashboardTransmissionRightsAndNominationsData
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_inner import ParticipantDashboardTransmissionRightsAndNominationsDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_inner_values_inner import ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_inner_values_inner_nomination_restriction import ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInnerNominationRestriction
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data import ParticipantDashboardTransmissionRightsAndNominationsGraphData
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus_inner import ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtusInner
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_graph_data_mtus_inner_values_inner import ParticipantDashboardTransmissionRightsAndNominationsGraphDataMtusInnerValuesInner
from empire_platform_api_public_client.models.participant_organisation_details import ParticipantOrganisationDetails
from empire_platform_api_public_client.models.participant_overview_data import ParticipantOverviewData
from empire_platform_api_public_client.models.participant_overview_data_contact_information import ParticipantOverviewDataContactInformation
from empire_platform_api_public_client.models.participant_overview_data_finance_overview import ParticipantOverviewDataFinanceOverview
from empire_platform_api_public_client.models.participant_overview_data_organisation_members import ParticipantOverviewDataOrganisationMembers
from empire_platform_api_public_client.models.permission import Permission
from empire_platform_api_public_client.models.platform_appearance import PlatformAppearance
from empire_platform_api_public_client.models.profile import Profile
from empire_platform_api_public_client.models.profile_details import ProfileDetails
from empire_platform_api_public_client.models.profile_user import ProfileUser
from empire_platform_api_public_client.models.profile_user_organisation import ProfileUserOrganisation
from empire_platform_api_public_client.models.public_aggregated_nominations_overview_response import PublicAggregatedNominationsOverviewResponse
from empire_platform_api_public_client.models.public_aggregated_nominations_overview_response_mtus_inner import PublicAggregatedNominationsOverviewResponseMtusInner
from empire_platform_api_public_client.models.public_aggregated_nominations_overview_response_mtus_inner_values_inner import PublicAggregatedNominationsOverviewResponseMtusInnerValuesInner
from empire_platform_api_public_client.models.public_auction import PublicAuction
from empire_platform_api_public_client.models.public_auction_batch import PublicAuctionBatch
from empire_platform_api_public_client.models.public_auction_bid_status import PublicAuctionBidStatus
from empire_platform_api_public_client.models.public_auction_status import PublicAuctionStatus
from empire_platform_api_public_client.models.public_day_ahead_auction import PublicDayAheadAuction
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_mtu_results import PublicDayAheadOrIntraDayAuctionMtuResults
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_mtu_results_bids_inner import PublicDayAheadOrIntraDayAuctionMtuResultsBidsInner
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_results import PublicDayAheadOrIntraDayAuctionResults
from empire_platform_api_public_client.models.public_intra_day_auction import PublicIntraDayAuction
from empire_platform_api_public_client.models.public_long_term_auction import PublicLongTermAuction
from empire_platform_api_public_client.models.public_long_term_auction_results import PublicLongTermAuctionResults
from empire_platform_api_public_client.models.purchased_by_organisation import PurchasedByOrganisation
from empire_platform_api_public_client.models.reserve_price_publish_type import ReservePricePublishType
from empire_platform_api_public_client.models.return_auction import ReturnAuction
from empire_platform_api_public_client.models.sage_code import SageCode
from empire_platform_api_public_client.models.secondary_market_capacity_price_mtu import SecondaryMarketCapacityPriceMtu
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry import SecondaryMarketDayAheadOrIntraDayNoticeboardEntry
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_details import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryDetails
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_matching import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response_mtus_inner import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponseMtusInner
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_options import SecondaryMarketDayAheadOrIntraDayNoticeboardOptions
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_response_options import SecondaryMarketDayAheadOrIntraDayNoticeboardResponseOptions
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request import SecondaryMarketDayAheadOrIntraDayTransferRequest
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request_mtus_inner import SecondaryMarketDayAheadOrIntraDayTransferRequestMtusInner
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request_options import SecondaryMarketDayAheadOrIntraDayTransferRequestOptions
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_transfer_request_options_mtus_inner import SecondaryMarketDayAheadOrIntraDayTransferRequestOptionsMtusInner
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_entry import SecondaryMarketLongTermNoticeboardEntry
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_entry_details import SecondaryMarketLongTermNoticeboardEntryDetails
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_entry_response import SecondaryMarketLongTermNoticeboardEntryResponse
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_options import SecondaryMarketLongTermNoticeboardOptions
from empire_platform_api_public_client.models.secondary_market_long_term_noticeboard_response_options import SecondaryMarketLongTermNoticeboardResponseOptions
from empire_platform_api_public_client.models.secondary_market_long_term_transfer_request_options import SecondaryMarketLongTermTransferRequestOptions
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry import SecondaryMarketNoticeboardEntry
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry_batch import SecondaryMarketNoticeboardEntryBatch
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry_status import SecondaryMarketNoticeboardEntryStatus
from empire_platform_api_public_client.models.secondary_market_return_request import SecondaryMarketReturnRequest
from empire_platform_api_public_client.models.secondary_market_return_request_batch import SecondaryMarketReturnRequestBatch
from empire_platform_api_public_client.models.secondary_market_return_request_status import SecondaryMarketReturnRequestStatus
from empire_platform_api_public_client.models.secondary_market_transfer_request import SecondaryMarketTransferRequest
from empire_platform_api_public_client.models.secondary_market_transfer_request_batch import SecondaryMarketTransferRequestBatch
from empire_platform_api_public_client.models.secondary_market_transfer_request_status import SecondaryMarketTransferRequestStatus
from empire_platform_api_public_client.models.secondary_market_transfer_request_type import SecondaryMarketTransferRequestType
from empire_platform_api_public_client.models.secondary_market_transfer_transmission_rights_mtu import SecondaryMarketTransferTransmissionRightsMtu
from empire_platform_api_public_client.models.settlement import Settlement
from empire_platform_api_public_client.models.settlement_item import SettlementItem
from empire_platform_api_public_client.models.settlement_per_source import SettlementPerSource
from empire_platform_api_public_client.models.settlement_source_type import SettlementSourceType
from empire_platform_api_public_client.models.settlement_sub_source_type import SettlementSubSourceType
from empire_platform_api_public_client.models.source_auction import SourceAuction
from empire_platform_api_public_client.models.source_auction_display_data import SourceAuctionDisplayData
from empire_platform_api_public_client.models.source_auction_result import SourceAuctionResult
from empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request import SubmitDayAheadOrIntraDayBidsRequest
from empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups_inner import SubmitDayAheadOrIntraDayBidsRequestBidGroupsInner
from empire_platform_api_public_client.models.submit_day_ahead_or_intra_day_bids_request_bid_groups_inner_bids_inner import SubmitDayAheadOrIntraDayBidsRequestBidGroupsInnerBidsInner
from empire_platform_api_public_client.models.submit_long_term_bids_request import SubmitLongTermBidsRequest
from empire_platform_api_public_client.models.submit_long_term_bids_request_bids_inner import SubmitLongTermBidsRequestBidsInner
from empire_platform_api_public_client.models.submit_nominations_mtu import SubmitNominationsMtu
from empire_platform_api_public_client.models.submit_timescale_nominations_request import SubmitTimescaleNominationsRequest
from empire_platform_api_public_client.models.system_message_category import SystemMessageCategory
from empire_platform_api_public_client.models.timescale_nomination_mtu_status import TimescaleNominationMtuStatus
from empire_platform_api_public_client.models.timescale_nomination_options import TimescaleNominationOptions
from empire_platform_api_public_client.models.timescale_nomination_options_window_timing import TimescaleNominationOptionsWindowTiming
from empire_platform_api_public_client.models.timescale_nomination_status import TimescaleNominationStatus
from empire_platform_api_public_client.models.timescale_nomination_type import TimescaleNominationType
from empire_platform_api_public_client.models.timescale_nomination_window_status import TimescaleNominationWindowStatus
from empire_platform_api_public_client.models.timescale_nominations import TimescaleNominations
from empire_platform_api_public_client.models.timescale_nominations_mtus_inner import TimescaleNominationsMtusInner
from empire_platform_api_public_client.models.timescale_nominations_mtus_inner_current_nomination import TimescaleNominationsMtusInnerCurrentNomination
from empire_platform_api_public_client.models.transmission_rights_overview import TransmissionRightsOverview
from empire_platform_api_public_client.models.transmission_rights_overview_mtus_inner import TransmissionRightsOverviewMtusInner
from empire_platform_api_public_client.models.transmission_rights_overview_mtus_inner_values_inner import TransmissionRightsOverviewMtusInnerValuesInner
from empire_platform_api_public_client.models.transmission_rights_overview_mtus_inner_values_inner_timescales_inner import TransmissionRightsOverviewMtusInnerValuesInnerTimescalesInner
from empire_platform_api_public_client.models.uiosi_not_resold import UiosiNotResold
from empire_platform_api_public_client.models.uiosi_overview import UiosiOverview
from empire_platform_api_public_client.models.uiosi_overview_per_mtu import UiosiOverviewPerMtu
from empire_platform_api_public_client.models.uiosi_resold import UiosiResold
from empire_platform_api_public_client.models.unread_messages_response import UnreadMessagesResponse
from empire_platform_api_public_client.models.update_day_ahead_or_intra_day_default_bid_request import UpdateDayAheadOrIntraDayDefaultBidRequest
from empire_platform_api_public_client.models.update_default_nomination_request import UpdateDefaultNominationRequest
from empire_platform_api_public_client.models.update_long_term_default_bid_request import UpdateLongTermDefaultBidRequest
from empire_platform_api_public_client.models.update_profile_details_request import UpdateProfileDetailsRequest
from empire_platform_api_public_client.models.update_user_request import UpdateUserRequest
from empire_platform_api_public_client.models.user import User
from empire_platform_api_public_client.models.user_organisation import UserOrganisation
from empire_platform_api_public_client.models.user_preferences import UserPreferences
from empire_platform_api_public_client.models.user_preferences_general_notifications import UserPreferencesGeneralNotifications
from empire_platform_api_public_client.models.user_preferences_subscription_notifications import UserPreferencesSubscriptionNotifications
from empire_platform_api_public_client.models.user_role import UserRole
from empire_platform_api_public_client.models.user_status import UserStatus
from empire_platform_api_public_client.models.vat_rate_type import VatRateType
from empire_platform_api_public_client.models.version import Version
from empire_platform_api_public_client.models.zendesk_chat_token_response import ZendeskChatTokenResponse



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.long_term_auction_bid_sort_by import LongTermAuctionBidSortBy  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestLongTermAuctionBidSortBy(unittest.TestCase):
    """LongTermAuctionBidSortBy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testLongTermAuctionBidSortBy(self):
        """Test LongTermAuctionBidSortBy"""
        # inst = LongTermAuctionBidSortBy()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt
from empire_platform_api_public_client.models.border_direction import BorderDirection

class AggregatedNominationsMtuNettedNominations(BaseModel):
    """
    * `flow` - The smaller direction and deduct its aggregated nomination value from the larger direction's aggregated nomination value to get the flow 
    """
    direction: BorderDirection = Field(...)
    flow: StrictInt = Field(..., description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    __properties = ["direction", "flow"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AggregatedNominationsMtuNettedNominations:
        """Create an instance of AggregatedNominationsMtuNettedNominations from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AggregatedNominationsMtuNettedNominations:
        """Create an instance of AggregatedNominationsMtuNettedNominations from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AggregatedNominationsMtuNettedNominations.parse_obj(obj)

        _obj = AggregatedNominationsMtuNettedNominations.parse_obj({
            "direction": obj.get("direction"),
            "flow": obj.get("flow")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.message import Message  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestMessage(unittest.TestCase):
    """Message unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Message
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Message`
        """
        model = empire_platform_api_public_client.models.message.Message()  # noqa: E501
        if include_optional :
            return Message(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                received_at = '2022-01-04T00:00Z', 
                category = 'GENERAL', 
                sender = 'ICO', 
                severity = 'CRITICAL_ALERT', 
                type = 'AUCTION', 
                subject = '', 
                body = '', 
                read = True, 
                entity_id = '', 
                attachment = empire_platform_api_public_client.models.attachment.Attachment(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    file_name = '', 
                    file_size = 0, 
                    mime_type = '', 
                    url = '', )
            )
        else :
            return Message(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                received_at = '2022-01-04T00:00Z',
                category = 'GENERAL',
                sender = 'ICO',
                severity = 'CRITICAL_ALERT',
                type = 'AUCTION',
                subject = '',
                body = '',
        )
        """

    def testMessage(self):
        """Test Message"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from empire_platform_api_public_client.models.auction_bid_status import AuctionBidStatus
from empire_platform_api_public_client.models.bid_value import BidValue
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_bid_group_bids_inner_bid_results import DayAheadOrIntraDayAuctionBidGroupBidsInnerBidResults

class LongTermAuctionBid(BaseModel):
    """
    LongTermAuctionBid
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    value: BidValue = Field(...)
    updated_at: datetime = Field(..., alias="updatedAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    status: AuctionBidStatus = Field(...)
    results: Optional[DayAheadOrIntraDayAuctionBidGroupBidsInnerBidResults] = None
    __properties = ["id", "value", "updatedAt", "status", "results"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LongTermAuctionBid:
        """Create an instance of LongTermAuctionBid from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of value
        if self.value:
            _dict['value'] = self.value.to_dict()
        # override the default output from pydantic by calling `to_dict()` of results
        if self.results:
            _dict['results'] = self.results.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LongTermAuctionBid:
        """Create an instance of LongTermAuctionBid from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LongTermAuctionBid.parse_obj(obj)

        _obj = LongTermAuctionBid.parse_obj({
            "id": obj.get("id"),
            "value": BidValue.from_dict(obj.get("value")) if obj.get("value") is not None else None,
            "updated_at": obj.get("updatedAt"),
            "status": obj.get("status"),
            "results": DayAheadOrIntraDayAuctionBidGroupBidsInnerBidResults.from_dict(obj.get("results")) if obj.get("results") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class AuctionAllocationResolution(str, Enum):
    """
    AuctionAllocationResolution
    """

    """
    allowed enum values
    """
    RES_1_KW = 'RES_1_KW'
    RES_100_KW = 'RES_100_KW'
    RES_500_KW = 'RES_500_KW'
    RES_1_MW = 'RES_1_MW'

    @classmethod
    def from_json(cls, json_str: str) -> AuctionAllocationResolution:
        """Create an instance of AuctionAllocationResolution from a JSON string"""
        return AuctionAllocationResolution(json.loads(json_str))


